<?PHP @template::ran_directly();

// loop all departments and do the import
foreach (helpdesk::get_all_departments() as $department)
	{
	// start the import for this department
	$ticket_ids=array();
	$conn=helpdesk::pop3_login(sx($department['host']), $department['port'], sx($department['username']), sx($department['password']), 'INBOX', false, $department['imap_connection_string']);

	foreach (helpdesk::pop3_import($conn) as $key => $import)
		{
		// If the incoming e-mail is from a department address and that department is not a contact form then do not process the ticket.
		if (!helpdesk::is_contact_form($department['id'])&&helpdesk::get_department('', $import['from'])) 
			{
			helpdesk::pop3_delete_message($conn, $key);
			continue; 
			}

		// figure out what user we are talking to or create the user if he/she is new!
		$user_info=helpdesk::sort_user($import, $department, $default_admin_path); // pr($user_info);
		$customer_id=$user_info['customer_id'];
		$user_id=$user_info['user_id'];
		$admin_id=$user_info['admin_id'];

		// added v1.9.1
		// covers tickets sent in outside the helpdesk where the package ID is not set in the header
		// ------------------------------------------------------------------------------------------
		if (!$import['package_id'] && $customer_id) 
			{
			//no package ID, get the first one that has good support
			$packages = package::get_packages($customer_id, true);
			foreach ($packages as $package)
				{
				if (helpdesk::is_valid_package_id($package['id'], $customer_id))
					{
					$import['package_id'] = $package['id'];
					break;
					}
				}
			}
		// ------------------------------------------------------------------------------------------
		// END: added v1.9.1

		// check to see if this is a bounced message notification
		$ticket_id=false;
		if (!helpdesk::process_bounce($user_id, $import['from_name'], $import['subject'], $import['body']))
			{
			// create the ticket
			$ticket_id=helpdesk::create_ticket(
									$import['subject'], 
									$customer_id, 
									$user_id, 
									$admin_id, 
									$department['id'], 
									'Open',
									$department['ticket_creation'],
									$import['customer_area_id'],
									$department['require_valid_support_package'],
									$import['package_id']
									);
			}
		if (!$ticket_id) 
			{
			// mark the message as deleted
			helpdesk::pop3_delete_message($conn, $key); 
			continue; 
			} 

		$ticket_ids[$ticket_id]=$user_id;

		// log the run
		helpdesk::m3_helpdesk_parser_log("Importing mail: {$import['subject']}", $ticket_id, $import['header']);

		// add the reply
		$reply_id=helpdesk::log_reply($ticket_id, $admin_id, $customer_id, $user_id, $import['header'], $import['body']);

		// make sure the ticket is open
		helpdesk::reopen_ticket($ticket_id);

		// assign the ticket?
		if (!helpdesk::is_ticket_assigned($ticket_id)&&$admin_id&&$user_info['helpdesk_flood_protection']=='Disabled')
			{
			helpdesk::assign_ticket($ticket_id, $admin_id);
			}

		// add the attachment
		helpdesk::save_attachments($ticket_id, $reply_id, $import['attachments']);

		// send the auto-reply
		if ($department['enable_helpdesk_autoreply']=='Yes'&&!$admin_id)
			{
			$last_sent=helpdesk::last_message_sent($import['from'], 'helpdesk_auto_reply');
			$block=($last_sent&&($last_sent['created']+1800)<time());

			if (!$block)
				{
				helpdesk::send_auto_reply($department, $user_id, $ticket_id);
				}
			}

		// notify the admins of the reply
		helpdesk::notify_staff($department, $ticket_id, $reply_id);

		// notify the requestors
		if (($user_info['helpdesk_flood_protection']=='Disabled'||!$user_info['helpdesk_flood_protection'])&&$admin_id)
			{
			helpdesk::notify_requesters($department, $ticket_id, $reply_id, array($user_id));
			}

		// Add to the audit log
		if ($user_info['is_admin'])
			{
			$admin=admin::get($admin_id);
			$who=sx("<b>{$admin['first_name']} {$admin['last_name']}</b>");
			}
		else
			{
			$user=user::get('', $user_id);
			$who=sx("<b>{$user['first_name']} {$user['last_name']}</b> (Requester)");
			}
		helpdesk::add_audit_log($ticket_id, $admin_id, "{$who} ".w('replied_to_the_ticket', 0));

		// mark the message as deleted
		helpdesk::pop3_delete_message($conn, $key);
		}

	// run flood detection
	foreach ($ticket_ids as $ticket_id => $user_id)
		{
		if (helpdesk::flood_protection($user_id, $ticket_id))
			{
			// notify staff that flood protection is enabled.
			// helpdesk::notify_staff_flood_protection_enabled($department['id'], $ticket_id);

			$string_ticket_id=helpdesk::get_string_ticket_id($ticket_id);
			helpdesk::m3_helpdesk_parser_log("Flood protection enabled for ticket #{$string_ticket_id}.", $ticket_id);
			}
		}

	// commit to the delete
	helpdesk::pop3_delete_all($conn);

	// close the session
	helpdesk::pop3_logout($conn);
	}

// log the run
cron::add_job_log($job['id']);
?>