<?PHP
/**
 * SPBAS Storefront API Wrappers for the Order Forms API
 *
 * @package    Storefront_API_Wrappers_Order
 * @author     Andy Rockwell <support@solidphp.com>
 */
class api_order_forms extends api
	{
	/**
	* Does the TLD ID require an EPP code for transfer?
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $tld_id
	* @return array 
	*/
	function requires_epp_code($api_handler, $api_key, $mod, $task, $debug, $tld_id)
		{
		return api::query($api_handler, $api_key, $mod, $task, array('tld_id' => $tld_id), $debug);
		}

	/**
	* Do a whois on the domain
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $sld
	* @param string $tld_id
	* @return array 
	*/
	function whois($api_handler, $api_key, $mod, $task, $debug, $sld, $tld_id)
		{
		return api::query($api_handler, $api_key, $mod, $task, array('sld' => $sld, 'tld_id' => $tld_id), $debug);
		}

	/**
	* The registration period for the TLD ID
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $tld_id
	* @return array 
	*/
	function tld_years($api_handler, $api_key, $mod, $task, $debug, $tld_id)
		{
		return api::query($api_handler, $api_key, $mod, $task, array('tld_id' => $tld_id), $debug);
		}
	/**
	* Process the hosting form to collect domain options
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @param string $product_id
	* @param string $sku_id
	* @return array 
	*/
	function hosting($api_handler, $api_key, $mod, $task, $debug, $cart_session, $product_id, $sku_id, $addons, $package_id)
		{
		$data=array();
		$data['cart_session']=$cart_session;
		$data['product_id']=$product_id;
		$data['sku_id']=$sku_id;
		$data['addons']=$addons;
		$data['package_id']=$package_id;

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Builds language changer links
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $vat_number
	* @param integer $country_id
	* @return array 
	*/
	function available_languages($api_handler, $api_key, $mod, $task, $debug)
		{
		return api::query($api_handler, $api_key, $mod, $task, array(), $debug);
		}

	/**
	* Validate whether or not a V.A.T. number is valid
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $vat_number
	* @param integer $country_id
	* @return array 
	*/
	function validate_vat($api_handler, $api_key, $mod, $task, $debug, $vat_number, $country_id)
		{
		$data=array(
					'vat_number' => $vat_number, 
					'country_id' => $country_id, 
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Get an array of all data needed to display cart.php
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param integer $category_id
	* @param string $cart_session
	* @param string $customer_session
	* @return array 
	*/
	function cart($api_handler, $api_key, $mod, $task, $debug, $category_id, $cart_session, $customer_session)
		{
		$data=array(
					'category_id' => $category_id, 
					'cart_session' => $cart_session, 
					'customer_session' => $customer_session,
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Get an array of all data needed to display view_cart.php
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @param string $customer_session
	* @return array 
	*/
	function view_cart($api_handler, $api_key, $mod, $task, $debug, $cart_session, $customer_session)
		{
		$data=array(
					'cart_session' => $cart_session, 
					'customer_session' => $customer_session,
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Get an array of all data needed to display product.php
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @param string $customer_session
	* @param integer $product_id
	* @param integer $sku_id
	* @param integer $category_id
	* @return array 
	*/
	function product($api_handler, $api_key, $mod, $task, $debug, $cart_session, $customer_session, $product_id, $sku_id, $category_id)
		{
		$data=array(
					'cart_session' => $cart_session, 
					'customer_session' => $customer_session,
					'product_id' => $product_id, 
					'sku_id' => $sku_id,
					'category_id' => $category_id, 
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Get an array of all data needed to display payments.php
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $response_post base64_encode(serialize($_POST))
	* @param string $response_get base64_encode(serialize($_GET))
	* @return array 
	*/
	function payments($api_handler, $api_key, $mod, $task, $debug, $response_post, $response_get)
		{
		$data=array(
					'response_post' => $response_post, 
					'response_get' => $response_get,
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Get an array of all data needed to display payment.php
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @param string $customer_session
	* @param string $post_data base64_encode(serialize($_POST))
	* @return array 
	*/
	function payment($api_handler, $api_key, $mod, $task, $debug, $cart_session, $customer_session, $post_data)
		{
		$data=array(
					'cart_session' => $cart_session, 
					'customer_session' => $customer_session,
					'post_data' => $post_data,
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Get an array of all data needed to display order_complete.php
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $access_key
	* @return array 
	*/
	function order_complete($api_handler, $api_key, $mod, $task, $debug, $access_key)
		{
		$data=array('access_key' => $access_key);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Get an array of all data needed to display order_process.php
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @param string $customer_session
	* @param string $get base64_encode(serialize($_GET))
	* @param string $post base64_encode(serialize($_POST))
	* @return array 
	*/
	function order_process($api_handler, $api_key, $mod, $task, $debug, $cart_session, $customer_session, $get, $post)
		{
		$data=array(
					'cart_session' => $cart_session, 
					'customer_session' => $customer_session,
					'get' => $get, 
					'post' => $post,
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Get an array of all data needed to display order_process.php
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @param string $customer_session
	* @return array 
	*/
	function checkout($api_handler, $api_key, $mod, $task, $debug, $cart_session, $customer_session)
		{
		$data=array(
					'cart_session' => $cart_session, 
					'customer_session' => $customer_session,
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Get an array of all data needed to display private.php (down_for_maintenance.php)
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @return array 
	*/
	function down_for_maintenance($api_handler, $api_key, $mod, $task, $debug)
		{
		return api::query($api_handler, $api_key, $mod, $task, array(), $debug);
		}

	/**
	* Update the cart
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $product
	* @param string $checksum
	* @return array 
	*/
	function buy_now($api_handler, $api_key, $mod, $task, $debug, $product)
		{
		$data=array('product' => $product);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Update the cart
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @return array 
	*/
	function empty_cart($api_handler, $api_key, $mod, $task, $debug, $cart_session)
		{
		$data=array('cart_session' => $cart_session);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Update the cart
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @param string $customer_session
	* @param integer $qty
	* @param string $promotion_code
	* @return array 
	*/
	function update_cart($api_handler, $api_key, $mod, $task, $debug, $cart_session, $customer_session, $qty, $promotion_code)
		{
		$data=array(
					'cart_session' => $cart_session, 
					'customer_session' => $customer_session,
					'qty' => $qty,
					'promotion_code' => $promotion_code,
					'remove_promotion_code' => 0,
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Remove a promotion code from the cart
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @return array 
	*/
	function remove_promotion_code($api_handler, $api_key, $mod, $task, $debug, $cart_session)
		{
		$data=array(
					'cart_session' => $cart_session, 
					'remove_promotion_code' => 1,
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Remove an item from the cart
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @param integer $item_id
	* @return array 
	*/
	function remove_item($api_handler, $api_key, $mod, $task, $debug, $cart_session, $item_id)
		{
		$data=array(
					'cart_session' => $cart_session, 
					'qty' => "{$item_id}|0",
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Add a product (and addons) to the cart.
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @param integer $product_id
	* @param integer $sku_id
	* @param integer $package_id
	* @param string $addons `sku_id` from `m3_product_sku` in CSV
	* @param string $domain_options
	* @return array 
	*/
	function add_to_cart($api_handler, $api_key, $mod, $task, $debug, $cart_session, $product_id, $sku_id, $package_id, $addons, $domain_options=array())
		{
		$data=array(
					'cart_session' => $cart_session, 
					'product_id' => $product_id, 
					'sku_id' => $sku_id, 
					'package_id' => $package_id, 
					'addons' => $addons, 
					'domain_options' => $domain_options, 
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Add a product (and addons) to the cart.
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @param integer $product_id
	* @param integer $sku_id
	* @param integer $package_id
	* @param string $addons `sku_id` from `m3_product_sku` in CSV
	* @return array 
	*/
	function extended_requirements($api_handler, $api_key, $mod, $task, $debug, $cart_session, $product_id, $sku_id, $package_id, $addons)
		{
		$data=array(
					'cart_session' => $cart_session, 
					'product_id' => $product_id, 
					'sku_id' => $sku_id, 
					'package_id' => $package_id, 
					'addons' => $addons, 
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Process the Ideal pay gateway module response.
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @param string $customer_session
	* @param array $post_data
	* @return array 
	*/
	function process_ideal_gateway_response($api_handler, $api_key, $mod, $task, $debug, $cart_session, $customer_session, $post_data)
		{
		$data=array(
					'cart_session' => $cart_session, 
					'customer_session' => $customer_session, 
					'post_data' => $post_data, 
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Change the currency of a cart session.
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $session_id `m3_cart_sessions` -> `session_id` or $_COOKIE['cart_session']
	* @param integer $price_sheet_id
	* @param integer $order_form_id
	* @return array 
	*/
	function change_currency($api_handler, $api_key, $mod, $task, $debug, $session_id, $price_sheet_id, $order_form_id)
		{
		$data=array(
					'session_id' => $session_id, 
					'price_sheet_id' => $price_sheet_id, 
					'order_form_id' => $order_form_id, 
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Check to see if the e-mail address in question is already taken.
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $email
	* @return array 
	*/
	function whois_email($api_handler, $api_key, $mod, $task, $debug, $email)
		{
		$data=array('email' => $email);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Check to see if the username in question is already taken.
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $username
	* @return array 
	*/
	function whois_username($api_handler, $api_key, $mod, $task, $debug, $username)
		{
		$data=array('username' => $username);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Create a new customer & primary user account.
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @param string $first_name
	* @param string $last_name
	* @param string $company_name
	* @param string $email
	* @param string $username
	* @param string $password
	* @param string $business_name
	* @param string $address
	* @param string $city
	* @param integer $country_id
	* @param integer $state_id
	* @param string $province
	* @param string $postal_code
	* @param string $phone
	* @param string $notes
	* @param string $question
	* @param string $answer
	* @param string $tos
	* @param string $ip
	* @param string $vat_number
	* @return array 
	*/
	function create_customer_account(
								$api_handler, 
								$api_key, 
								$mod, 
								$task, 
								$debug, 
								$cart_session, 
								$first_name, 
								$last_name, 
								$company_name, 
								$email, 
								$username, 
								$password, 
								$business_name, 
								$address, 
								$city, 
								$country_id, 
								$state_id, 
								$province, 
								$postal_code, 
								$phone, 
								$notes, 
								$question, 
								$answer, 
								$tos, 
								$ip, 
								$vat_number=''
								)
		{
		$data=array(
					'cart_session' => $cart_session, 
					'first_name' => $first_name, 
					'last_name' => $last_name, 
					'company_name' => $company_name, 
					'email' => $email, 
					'username' => $username, 
					'password' => $password, 
					'business_name' => $business_name, 
					'address' => $address, 
					'city' => $city, 
					'country_id' => $country_id, 
					'state_id' => $state_id, 
					'province' => $province, 
					'postal_code' => $postal_code, 
					'phone' => $phone, 
					'notes' => $notes, 
					'question' => $question, 
					'answer' => $answer, 
					'tos' => $tos, 
					'ip' => $ip, 
					'vat_number' => $vat_number, 
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Update the customer & user account.
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @param string $customer_session
	* @param string $first_name
	* @param string $last_name
	* @param string $company_name
	* @param string $business_name
	* @param string $address
	* @param string $city
	* @param integer $country_id
	* @param integer $state_id
	* @param string $province
	* @param string $postal_code
	* @param string $phone
	* @param string $tos
	* @param string $notes
	* @param string $vat_number
	* @return array 
	*/
	function update_customer_account(
								$api_handler, 
								$api_key, 
								$mod, 
								$task, 
								$debug, 
								$cart_session, 
								$customer_session, 
								$first_name, 
								$last_name, 
								$company_name,
								$business_name, 
								$address, 
								$city, 
								$country_id, 
								$state_id, 
								$province, 
								$postal_code, 
								$phone, 
								$tos, 
								$notes,
								$vat_number=''
								)
		{
		$data=array(
					'cart_session' => $cart_session, 
					'customer_session' => $customer_session, 
					'first_name' => $first_name, 
					'last_name' => $last_name, 
					'company_name' => $company_name, 
					'business_name' => $business_name, 
					'address' => $address, 
					'city' => $city, 
					'country_id' => $country_id, 
					'state_id' => $state_id, 
					'province' => $province, 
					'postal_code' => $postal_code, 
					'phone' => $phone, 
					'tos' => $tos, 
					'notes' => $notes, 
					'vat_number' => $vat_number, 
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Send the login request to create a new session.
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $email
	* @param string $password
	* @param string $ip
	* @return array 
	*/
	function login($api_handler, $api_key, $mod, $task, $debug, $email, $password, $ip)
		{
		$data=array(
					'email' => $email, 
					'password' => $password, 
					'ip' => $ip, 
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Send the resend password request.
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $email
	* @return array 
	*/
	function resend_password($api_handler, $api_key, $mod, $task, $debug, $email)
		{
		$data=array('email' => $email);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Get a complete array of customer & user data
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @param string $cart_session
	* @param string $customer_session
	* @return array 
	*/
	function customer_data_complete($api_handler, $api_key, $mod, $task, $debug, $cart_session, $customer_session)
		{
		$data=array(
					'cart_session' => $cart_session, 
					'customer_session' => $customer_session, 
					);

		return api::query($api_handler, $api_key, $mod, $task, $data, $debug);
		}

	/**
	* Start a new shopping cart session
	*
	* @uses This function is a wrapper for api::query()
	* @see api::query()
	*
	* @param string $api_handler
	* @param string $api_key
	* @param string $mod
	* @param string $task
	* @param boolean $debug
	* @return array 
	*/
	function start_session($api_handler, $api_key, $mod, $task, $debug)
		{
		return api::query($api_handler, $api_key, $mod, $task, array(), $debug);
		}
	}
?>